Skip to contents

Parses advertised month ranges and publisher MD5 checksums. The complete rolling snapshot can contain several years. Results are cached only after this function is called. Source failures return NULL with a message.

Usage

sl_archive_index(
  dir = sl_cache_dir(),
  refresh = FALSE,
  url = "https://data.police.uk/data/archive/"
)

Arguments

dir

Cache directory.

refresh

Refresh the cached index.

url

Archive listing URL, normally the official source.

Value

A tibble with archive name, snapshot month, coverage range, URL and MD5, or NULL if unavailable.

Examples

index <- readRDS(system.file("extdata", "archive-index.rds",
  package = "searchlight"
))
index[, c("archive_file", "month_start", "month_end")]
#> # A tibble: 3 × 3
#>   archive_file month_start month_end
#>   <chr>        <chr>       <chr>    
#> 1 2026-07.zip  2023-08     2026-07  
#> 2 2026-06.zip  2023-07     2026-06  
#> 3 2026-05.zip  2023-06     2026-05