Skip to contents

Returns the cache path without creating it. Acquisition functions explicitly create and write to this directory. Set options(searchlight.cache_dir = ...) to override the platform default, or pass an explicit dir.

Usage

sl_cache_dir()

Value

A character path.

Examples

sl_cache_dir()
#> [1] "/home/runner/.cache/R/searchlight"