Returns the cache path without creating it. Acquisition functions
explicitly
create and write to this directory. Set options(searchlight.cache_dir = ...)
to override the platform default, or pass an explicit dir.
Returns the cache path without creating it. Acquisition functions
explicitly
create and write to this directory. Set options(searchlight.cache_dir = ...)
to override the platform default, or pass an explicit dir.